==> vue-user-head-2.8.0.tgz: package/lib/mobile.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/user-head/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import { iconUser } from "@dft-vue-2-opentiny/vue-icon";
import "@dft-vue-2-opentiny/vue-theme-mobile/user-head/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconUser: iconUser()
  },
  props: [].concat(props, ["min", "round", "color", "backgroundColor", "type", "modelValue", "messageTotal", "messageType", "messageUpperLimit", "size"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-user-head"
  }, [_c("div", {
    class: ["tiny-mobile-user-head__portrait", {
      min: _vm.min,
      round: _vm.round
    }, _vm.type],
    style: Object.assign({}, _vm.state.style, {
      width: _vm.state.size + "px",
      height: _vm.state.size + "px"
    })
  }, [_vm._t("default", [_vm.type === "icon" ? _c(_vm.state.internalValue, {
    tag: "component",
    staticClass: "tiny-mobile-svg-size"
  }) : _vm._e(), _vm.type === "label" ? _c("span", {
    style: {
      fontSize: _vm.state.size * 0.3 + "px"
    },
    attrs: {
      "title": _vm.state.internalValue
    }
  }, [_vm._v(_vm._s(_vm.state.label))]) : _vm._e()])], 2), _vm.messageTotal ? _c("div", {
    class: ["tiny-mobile-user-head__message", {
      min: _vm.min,
      round: _vm.round,
      basic: _vm.messageType === "basic" || _vm.messageType === "icon"
    }],
    style: {
      left: _vm.state.size * 0.9 + "px"
    }
  }, [_vm._v(" " + _vm._s(_vm.state.message) + " ")]) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-user-head-2.21.0.tgz: package/lib/mobile.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/user-head/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconUser } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme-mobile/user-head/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconUser: iconUser()
  },
  props: [].concat(props, ["min", "round", "color", "backgroundColor", "type", "modelValue", "messageTotal", "messageType", "messageUpperLimit", "size"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-user-head"
  }, [_c("div", {
    class: ["tiny-mobile-user-head__portrait", {
      min: _vm.min,
      round: _vm.round
    }, _vm.type],
    style: Object.assign({}, _vm.state.style, {
      width: _vm.state.size + "px",
      height: _vm.state.size + "px"
    })
  }, [_vm._t("default", function() {
    return [_vm.type === "icon" ? _c(_vm.state.internalValue, {
      tag: "component",
      staticClass: "tiny-mobile-svg-size"
    }) : _vm._e(), _vm.type === "label" ? _c("span", {
      style: {
        fontSize: _vm.state.size * 0.3 + "px"
      },
      attrs: {
        "title": _vm.state.internalValue
      }
    }, [_vm._v(_vm._s(_vm.state.label))]) : _vm._e()];
  })], 2), _vm.messageTotal ? _c("div", {
    class: ["tiny-mobile-user-head__message", {
      min: _vm.min,
      round: _vm.round,
      basic: _vm.messageType === "basic" || _vm.messageType === "icon"
    }],
    style: {
      left: _vm.state.size * 0.9 + "px"
    }
  }, [_vm._v(" " + _vm._s(_vm.state.message) + " ")]) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
